@@ -2,7 +2,7 @@ package Config::IniFiles;
 
 use vars qw($VERSION);
 
-$VERSION = '2.74';
+$VERSION = '2.76';
 
 require 5.004;
 use strict;
@@ -20,6 +20,8 @@ use File::Temp qw/ tempfile /;
 
 #   $Header: /home/shlomi/progs/perl/cpan/Config/IniFiles/config-inifiles-cvsbackup/config-inifiles/IniFiles.pm,v 2.41 2003-12-08 10:50:56 domq Exp $
 
+=encoding utf8
+
 =head1 NAME
 
 Config::IniFiles - A module for reading .ini-style configuration files.
@@ -274,7 +276,7 @@ or
 If set to 0 (the default if not importing), these comments are treated
 like ordinary ones.
 
-The L</WriteConfig|WriteConfig(-delta=>1)> form will output such
+The L</WriteConfig|WriteConfig($filename, -delta=>1)> form will output such
 comments to indicate deleted sections or parameters. This way,
 reloading a delta file using the same imported object produces the
 same results in memory again. See L<IMPORT / DELTA FEATURES> for more
@@ -1231,7 +1233,7 @@ sub ReadConfig
     $self->{mysects} = []; # A pair of hashes to remember which params are loaded
     $self->{myparms} = {}; # or set using the API vs. imported - useful for
     $self->{peCMT}  = {};  # this will store trailing comments at the end of single-lined params
-    # import shadowing, see below, and WriteConfig(-delta=>1)
+    # import shadowing, see below, and WriteConfig($fn, -delta=>1)
 
     if( defined $self->{imported} ) {
         # Run up the import tree to the top, then reload coming
@@ -1640,8 +1642,8 @@ sub GetWriteMode
 =head2 WriteConfig ($filename [, %options])
 
 Writes out a new copy of the configuration file.  A temporary file
-(ending in '-new') is written out and then renamed to the specified
-filename.  Also see B<BUGS> below.
+is written out and then renamed to the specified filename.  Also see
+B<BUGS> below.
 
 If C<-delta> is set to a true value in %options, and this object was
 imported from another (see L</new>), only the differences between this
@@ -1685,7 +1687,7 @@ sub _write_config_to_filename
 
         # Convert the filehandle to a "text" filehandle suitable for use
         # on Windows (and other platforms).
-        # 
+        #
         # This may break compatibility for ultra-old perls (ones before 5.6.0)
         # so I say - Good Riddance!
         if ($^O =~ m/\AMSWin/)
@@ -2975,7 +2977,7 @@ is, if one calls
 
    $overlay->setval("section1", "arg1", "anotherval");
    $overlay->newval("section3", "arg3", "val3");
-   $overlay->WriteConfig(-delta=>1);
+   $overlay->WriteConfig('overlay.ini', -delta=>1);
 
 C<overlay.ini> would now contain
 
@@ -3002,7 +3004,7 @@ parameters like this,
 
    $overlay->DeleteSection("section2");
    $overlay->delval("section1", "arg0");
-   $overlay->WriteConfig(-delta=>1);
+   $overlay->WriteConfig('overlay.ini', -delta=>1);
 
 The I<overlay.ini> file would now read:
 
